@@ -1,3 +1,4 @@
 from .src.exergenics_etl import (
-    hello
+    hello,
+    get_time_now
 )
